guile-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Guile-commits] GNU Guile branch, stable-2.0, updated. v2.0.2-20-gf4a76a


From: Andy Wingo
Subject: [Guile-commits] GNU Guile branch, stable-2.0, updated. v2.0.2-20-gf4a76a3
Date: Sat, 23 Jul 2011 16:24:30 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU Guile".

http://git.savannah.gnu.org/cgit/guile.git/commit/?id=f4a76a315ad8f1f6f4dbdfbd2f030c6b299cb5a4

The branch, stable-2.0 has been updated
       via  f4a76a315ad8f1f6f4dbdfbd2f030c6b299cb5a4 (commit)
       via  a1a2ed534278b968767727485f84e5957c039c23 (commit)
      from  d322dc92ec8170320c68abc024eb683a0bf8ab00 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit f4a76a315ad8f1f6f4dbdfbd2f030c6b299cb5a4
Author: Andy Wingo <address@hidden>
Date:   Sat Jul 23 18:24:16 2011 +0200

    add (scripts help)
    
    * meta/guild.in (display-version): Use (ice-9 command-line)'s
      version-etc.
      (main): Dispatch --help to guild help.
    
    * module/scripts/help.scm: New file, a copy of list.scm, but with a
      better name.
    
    * module/Makefile.am: Add help.scm to the list.
    
    * module/scripts/list.scm: Change to be an alias to "help".
      (list-scripts): Restore this API.

commit a1a2ed534278b968767727485f84e5957c039c23
Author: Andy Wingo <address@hidden>
Date:   Sat Jul 23 17:50:37 2011 +0200

    more work on "guild list"
    
    * module/scripts/: Add %summary entries, and in many cases,
      %include-in-guild-list entries to inhibit a script from appearing in
      "guild list".  Update list.scm to respect this new variable.

-----------------------------------------------------------------------

Summary of changes:
 meta/guild.in                                  |   52 +++++++++---------------
 module/Makefile.am                             |    1 +
 module/scripts/api-diff.scm                    |    5 ++-
 module/scripts/autofrisk.scm                   |    5 ++-
 module/scripts/compile.scm                     |    2 +
 module/scripts/disassemble.scm                 |    4 +-
 module/scripts/display-commentary.scm          |    4 +-
 module/scripts/doc-snarf.scm                   |    4 +-
 module/scripts/frisk.scm                       |    5 ++-
 module/scripts/generate-autoload.scm           |    5 ++-
 module/scripts/{list.scm => help.scm}          |   45 ++++++++++----------
 module/scripts/lint.scm                        |    3 +
 module/scripts/list.scm                        |   38 +++++-------------
 module/scripts/punify.scm                      |    3 +
 module/scripts/read-rfc822.scm                 |    5 ++-
 module/scripts/read-scheme-source.scm          |    5 ++-
 module/scripts/read-text-outline.scm           |    5 ++-
 module/scripts/scan-api.scm                    |    5 ++-
 module/scripts/snarf-check-and-output-texi.scm |    5 ++-
 module/scripts/snarf-guile-m4-docs.scm         |    5 ++-
 module/scripts/summarize-guile-TODO.scm        |    5 ++-
 module/scripts/use2dot.scm                     |    4 +-
 22 files changed, 117 insertions(+), 98 deletions(-)
 copy module/scripts/{list.scm => help.scm} (75%)

diff --git a/meta/guild.in b/meta/guild.in
index bb9c37e..be4e5b5 100755
--- a/meta/guild.in
+++ b/meta/guild.in
@@ -25,6 +25,7 @@ exec guile $GUILE_FLAGS -e '(@@ (guild) main)' -s "$0" "$@"
 
 (define-module (guild)
   #:use-module (ice-9 getopt-long)
+  #:use-module (ice-9 command-line)
   #:autoload (ice-9 format) (format))
 
 ;; Hack to provide scripts with the bug-report address.
@@ -37,23 +38,11 @@ exec guile $GUILE_FLAGS -e '(@@ (guild) main)' -s "$0" "$@"
   '((help (single-char #\h))
     (version (single-char #\v))))
 
-(define (display-help)
-  (display "\
-Usage: guild --version
-       guild --help
-       guild PROGRAM [ARGS]
-
-If PROGRAM is \"list\" or omitted, display available scripts, otherwise
-PROGRAM is run with ARGS.
-"))
-
 (define (display-version)
-  (format #t "guild (GNU Guile ~A) ~A
-Copyright (C) 2010 Free Software Foundation, Inc.
-License LGPLv3+: GNU LGPL version 3 or later 
<http://gnu.org/licenses/lgpl.html>
-This is free software: you are free to change and redistribute it.
-There is NO WARRANTY, to the extent permitted by law.
-" (version) (effective-version)))
+  (version-etc "GNU Guile"
+               (effective-version)
+               #:command-name "guild"
+               #:license *LGPLv3+*))
 
 (define (find-script s)
   (resolve-module (list 'scripts (string->symbol s)) #:ensure #f))
@@ -62,27 +51,24 @@ There is NO WARRANTY, to the extent permitted by law.
   (if (defined? 'setlocale)
       (setlocale LC_ALL ""))
 
-  (let ((options (getopt-long args *option-grammar*
-                              #:stop-at-first-non-option #t)))
+  (let* ((options (getopt-long args *option-grammar*
+                               #:stop-at-first-non-option #t))
+         (args (option-ref options '() '())))
     (cond
      ((option-ref options 'help #f)
-      (display-help)
+      (apply (module-ref (resolve-module '(scripts help)) 'main) args)
       (exit 0))
      ((option-ref options 'version #f)
       (display-version)
       (exit 0))
+     ((find-script (if (null? args) "help" (car args)))
+      => (lambda (mod)
+           (exit (apply (module-ref mod 'main) (if (null? args)
+                                                   '()
+                                                   (cdr args))))))
      (else
-      (let ((args (option-ref options '() '())))
-        (cond ((find-script (if (null? args)
-                                "list"
-                                (car args)))
-               => (lambda (mod)
-                    (exit (apply (module-ref mod 'main) (if (null? args)
-                                                            '()
-                                                            (cdr args))))))
-              (else
-               (format (current-error-port)
-                       "guild: unknown script ~s~%" (car args))
-               (format (current-error-port)
-                       "Try `guild --help' for more information.~%")
-               (exit 1))))))))
+      (format (current-error-port)
+              "guild: unknown script ~s~%" (car args))
+      (format (current-error-port)
+              "Try `guild help' for more information.~%")
+      (exit 1)))))
diff --git a/module/Makefile.am b/module/Makefile.am
index 33d70bd..0787f20 100644
--- a/module/Makefile.am
+++ b/module/Makefile.am
@@ -153,6 +153,7 @@ SCRIPTS_SOURCES =                           \
   scripts/doc-snarf.scm                                \
   scripts/frisk.scm                            \
   scripts/generate-autoload.scm                        \
+  scripts/help.scm                             \
   scripts/lint.scm                             \
   scripts/list.scm                             \
   scripts/punify.scm                           \
diff --git a/module/scripts/api-diff.scm b/module/scripts/api-diff.scm
index b842b03..b2527b9 100644
--- a/module/scripts/api-diff.scm
+++ b/module/scripts/api-diff.scm
@@ -1,6 +1,6 @@
 ;;; api-diff --- diff guile-api.alist files
 
-;;     Copyright (C) 2002, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2002, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -46,6 +46,9 @@
   :autoload (srfi srfi-13) (string-tokenize)
   :export (api-diff))
 
+(define %include-in-guild-list #f)
+(define %summary "Show differences between two scan-api files.")
+
 (define (read-alist-file file)
   (with-input-from-file file
     (lambda () (read))))
diff --git a/module/scripts/autofrisk.scm b/module/scripts/autofrisk.scm
index 943c902..9bce06e 100644
--- a/module/scripts/autofrisk.scm
+++ b/module/scripts/autofrisk.scm
@@ -1,6 +1,6 @@
 ;;; autofrisk --- Generate module checks for use with auto* tools
 
-;;     Copyright (C) 2002, 2006, 2009 Free Software Foundation, Inc.
+;;     Copyright (C) 2002, 2006, 2009, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -62,6 +62,9 @@
   :use-module (scripts frisk)
   :export (autofrisk))
 
+(define %include-in-guild-list #f)
+(define %summary "Generate snippets for use in configure.ac files.")
+
 (define *recognized-keys* '(files-glob
                             non-critical-external
                             non-critical-internal
diff --git a/module/scripts/compile.scm b/module/scripts/compile.scm
index f9d6cca..0651c68 100644
--- a/module/scripts/compile.scm
+++ b/module/scripts/compile.scm
@@ -37,6 +37,8 @@
   #:use-module (ice-9 format)
   #:export (compile))
 
+(define %summary "Compile a file.")
+
 
 (define (fail . messages)
   (format (current-error-port) "error: ~{~a~}~%" messages)
diff --git a/module/scripts/disassemble.scm b/module/scripts/disassemble.scm
index 8907f6d..7dab2dd 100644
--- a/module/scripts/disassemble.scm
+++ b/module/scripts/disassemble.scm
@@ -1,6 +1,6 @@
 ;;; Disassemble --- Disassemble .go files into something human-readable
 
-;; Copyright 2005, 2008, 2009 Free Software Foundation, Inc.
+;; Copyright 2005, 2008, 2009, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -32,6 +32,8 @@
                 #:renamer (symbol-prefix-proc 'asm:))
   #:export (disassemble))
 
+(define %summary "Disassemble a compiled .go file.")
+
 (define (disassemble . files)
   (for-each (lambda (file)
               (asm:disassemble (load-objcode file)))
diff --git a/module/scripts/display-commentary.scm 
b/module/scripts/display-commentary.scm
index 5bd249c..81d7907 100644
--- a/module/scripts/display-commentary.scm
+++ b/module/scripts/display-commentary.scm
@@ -1,6 +1,6 @@
 ;;; display-commentary --- As advertized
 
-;;     Copyright (C) 2001, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2001, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -33,6 +33,8 @@
   :use-module (ice-9 documentation)
   :export (display-commentary))
 
+(define %summary "Display the Commentary section from a file or module.")
+
 (define (display-commentary-one file)
   (format #t "~A commentary:\n~A" file (file-commentary file)))
 
diff --git a/module/scripts/doc-snarf.scm b/module/scripts/doc-snarf.scm
index b7fbc99..fa3dfb3 100644
--- a/module/scripts/doc-snarf.scm
+++ b/module/scripts/doc-snarf.scm
@@ -1,6 +1,6 @@
 ;;; doc-snarf --- Extract documentation from source files
 
-;;     Copyright (C) 2001, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2001, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -83,6 +83,8 @@ This procedure foos, or bars, depending on the argument 
@var{braz}.
   :use-module (ice-9 rdelim)
   :export (doc-snarf))
 
+(define %summary "Snarf out documentation from a file.")
+
 (define command-synopsis
   '((version (single-char #\v) (value #f))
     (help    (single-char #\h) (value #f))
diff --git a/module/scripts/frisk.scm b/module/scripts/frisk.scm
index c452ede..a8f7923 100644
--- a/module/scripts/frisk.scm
+++ b/module/scripts/frisk.scm
@@ -1,6 +1,6 @@
 ;;; frisk --- Grok the module interfaces of a body of files
 
-;;     Copyright (C) 2002, 2006, 2010 Free Software Foundation, Inc.
+;;     Copyright (C) 2002, 2006, 2010, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -103,6 +103,9 @@
            mod-up-ls mod-down-ls mod-int?
            edge-type edge-up edge-down))
 
+(define %include-in-guild-list #f)
+(define %summary "Show dependency information for a module.")
+
 (define *default-module* '(guile-user))
 
 (define (grok-proc default-module note-use!)
diff --git a/module/scripts/generate-autoload.scm 
b/module/scripts/generate-autoload.scm
index 7819310..90f524b 100644
--- a/module/scripts/generate-autoload.scm
+++ b/module/scripts/generate-autoload.scm
@@ -1,6 +1,6 @@
 ;;; generate-autoload --- Display define-module form with autoload info
 
-;;     Copyright (C) 2001, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2001, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -59,6 +59,9 @@
 (define-module (scripts generate-autoload)
   :export (generate-autoload))
 
+(define %include-in-guild-list #f)
+(define %summary "Generate #:autoload clauses for a module.")
+
 (define (autoload-info file)
   (let ((p (open-input-file file)))
     (let loop ((form (read p)) (module-name #f) (exports '()))
diff --git a/module/scripts/lint.scm b/module/scripts/lint.scm
index aa74fb6..cea425e 100644
--- a/module/scripts/lint.scm
+++ b/module/scripts/lint.scm
@@ -105,6 +105,9 @@
   #:use-module (ice-9 format)
   #:export (lint))
 
+(define %include-in-guild-list #f)
+(define %summary "Check for bugs and style errors in a Scheme file.")
+
 (define (lint filename)
   (let ((module-name (scan-file-for-module-name filename))
        (free-vars (uniq (scan-file-for-free-variables filename))))
diff --git a/module/scripts/list.scm b/module/scripts/list.scm
index 6ffc016..0f1d715 100644
--- a/module/scripts/list.scm
+++ b/module/scripts/list.scm
@@ -26,10 +26,11 @@
 ;;; Code:
 
 (define-module (scripts list)
-  #:use-module (ice-9 format)
-  #:use-module ((srfi srfi-1) #:select (fold append-map))
   #:export (list-scripts))
 
+(define %include-in-guild-list #f)
+(define %summary "An alias for \"help\".")
+
 
 (define (directory-files dir)
   (if (and (file-exists? dir) (file-is-directory? dir))
@@ -79,30 +80,11 @@
                   %load-path)
       string<?))))
 
-(define (main . args)
-  (display "\
-Usage: guild COMMAND [ARGS]
-
-  guild runs command-line scripts provided by GNU Guile and related
-  programs.  See \"Using Guile Tools\" in the Guile manual, for more
-  information.
-
-Commands:
-")
+(define (list-scripts . args)
+  (for-each (lambda (x)
+              ;; would be nice to show a summary.
+              (format #t "~A\n" x))
+            (find-submodules '(scripts))))
 
-  (for-each
-   (lambda (name)
-     (let* ((modname `(scripts ,(string->symbol name)))
-            (mod (resolve-module modname #:ensure #f))
-            (summary (and mod (and=> (module-variable mod '%summary)
-                                     variable-ref))))
-       (if summary
-           (format #t "  ~A ~32t~a\n" name summary)
-           (format #t "  ~A\n" name))))
-   (find-submodules '(scripts)))
-
-  (display "\
-
-If COMMAND is \"list\" or omitted, display available scripts, otherwise
-COMMAND is run with ARGS.
-"))
+(define (main . args)
+  (apply (@@ (scripts help) main) args))
diff --git a/module/scripts/punify.scm b/module/scripts/punify.scm
index 1627722..6b33ac5 100644
--- a/module/scripts/punify.scm
+++ b/module/scripts/punify.scm
@@ -41,6 +41,9 @@
 (define-module (scripts punify)
   :export (punify))
 
+(define %include-in-guild-list #f)
+(define %summary "Strip comments and whitespace from a Scheme file.")
+
 (define (write-punily form)
   (cond ((and (list? form) (not (null? form)))
          (let ((first (car form)))
diff --git a/module/scripts/read-rfc822.scm b/module/scripts/read-rfc822.scm
index c0a54f2..08f3fb9 100644
--- a/module/scripts/read-rfc822.scm
+++ b/module/scripts/read-rfc822.scm
@@ -1,6 +1,6 @@
 ;;; read-rfc822 --- Validate RFC822 file by displaying it to stdout
 
-;;     Copyright (C) 2002, 2004, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2002, 2004, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -49,6 +49,9 @@
   :autoload (srfi srfi-13) (string-join)
   :export (read-rfc822 read-rfc822-silently))
 
+(define %include-in-guild-list #f)
+(define %summary "Validate an RFC822-style file.")
+
 (define from-line-rx   (make-regexp "^From "))
 (define header-name-rx (make-regexp "^([^:]+):[ \t]*"))
 (define header-cont-rx (make-regexp "^[ \t]+"))
diff --git a/module/scripts/read-scheme-source.scm 
b/module/scripts/read-scheme-source.scm
index b48a88f..1bca6a4 100644
--- a/module/scripts/read-scheme-source.scm
+++ b/module/scripts/read-scheme-source.scm
@@ -1,6 +1,6 @@
 ;;; read-scheme-source --- Read a file, recognizing scheme forms and comments
 
-;;     Copyright (C) 2001, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2001, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -91,6 +91,9 @@
            quoted?
            clump))
 
+(define %include-in-guild-list #f)
+(define %summary "Print a parsed representation of a Scheme file.")
+
 ;; Try to figure out what FORM is and its various attributes.
 ;; Call proc NOTE! with key (a symbol) and value.
 ;;
diff --git a/module/scripts/read-text-outline.scm 
b/module/scripts/read-text-outline.scm
index 64221fb..d0933bb 100644
--- a/module/scripts/read-text-outline.scm
+++ b/module/scripts/read-text-outline.scm
@@ -1,6 +1,6 @@
 ;;; read-text-outline --- Read a text outline and display it as a sexp
 
-;;     Copyright (C) 2002, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2002, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -118,6 +118,9 @@
   :autoload (ice-9 rdelim) (read-line)
   :autoload (ice-9 getopt-long) (getopt-long))
 
+(define %include-in-guild-list #f)
+(define %summary "Convert textual outlines to s-expressions.")
+
 (define (?? symbol)
   (let ((name (symbol->string symbol)))
     (string=? "?" (substring name (1- (string-length name))))))
diff --git a/module/scripts/scan-api.scm b/module/scripts/scan-api.scm
index 9236f87..86d07fc 100644
--- a/module/scripts/scan-api.scm
+++ b/module/scripts/scan-api.scm
@@ -1,6 +1,6 @@
 ;;; scan-api --- Scan and group interpreter and libguile interface elements
 
-;;     Copyright (C) 2002, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2002, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -65,6 +65,9 @@
   :use-module (ice-9 regex)
   :export (scan-api))
 
+(define %include-in-guild-list #f)
+(define %summary "Generate an API description for a Guile extension.")
+
 (define put set-object-property!)
 (define get object-property)
 
diff --git a/module/scripts/snarf-check-and-output-texi.scm 
b/module/scripts/snarf-check-and-output-texi.scm
index f92c833..6ca07a1 100644
--- a/module/scripts/snarf-check-and-output-texi.scm
+++ b/module/scripts/snarf-check-and-output-texi.scm
@@ -1,6 +1,6 @@
 ;;; snarf-check-and-output-texi --- called by the doc snarfer.
 
-;;     Copyright (C) 2001, 2002, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2001, 2002, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -26,6 +26,9 @@
     :use-module (ice-9 match)
     :export (snarf-check-and-output-texi))
 
+(define %include-in-guild-list #f)
+(define %summary "Transform snarfed .doc files into texinfo documentation.")
+
 ;;; why aren't these in some module?
 
 (define-macro (when cond . body)
diff --git a/module/scripts/snarf-guile-m4-docs.scm 
b/module/scripts/snarf-guile-m4-docs.scm
index 05c305e..4e59f53 100644
--- a/module/scripts/snarf-guile-m4-docs.scm
+++ b/module/scripts/snarf-guile-m4-docs.scm
@@ -1,6 +1,6 @@
 ;;; snarf-guile-m4-docs --- Parse guile.m4 comments for texi documentation
 
-;;     Copyright (C) 2002, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2002, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -35,6 +35,9 @@
   :use-module (ice-9 rdelim)
   :export (snarf-guile-m4-docs))
 
+(define %include-in-guild-list #f)
+(define %summary "Snarf out texinfo documentation from .m4 files.")
+
 (define (display-texi lines)
   (display "@deffn {Autoconf Macro}")
   (for-each (lambda (line)
diff --git a/module/scripts/summarize-guile-TODO.scm 
b/module/scripts/summarize-guile-TODO.scm
index ee4f88c..8b119e0 100644
--- a/module/scripts/summarize-guile-TODO.scm
+++ b/module/scripts/summarize-guile-TODO.scm
@@ -1,6 +1,6 @@
 ;;; summarize-guile-TODO --- Display Guile TODO list in various ways
 
-;;     Copyright (C) 2002, 2006, 2010 Free Software Foundation, Inc.
+;;     Copyright (C) 2002, 2006, 2010, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -73,6 +73,9 @@
   :autoload (ice-9 common-list) (remove-if-not)
   :export (summarize-guile-TODO))
 
+(define %include-in-guild-list #f)
+(define %summary "A quaint relic of the past.")
+
 (define put set-object-property!)
 (define get object-property)
 
diff --git a/module/scripts/use2dot.scm b/module/scripts/use2dot.scm
index ab97afb..975a9c4 100644
--- a/module/scripts/use2dot.scm
+++ b/module/scripts/use2dot.scm
@@ -1,6 +1,6 @@
 ;;; use2dot --- Display module dependencies as a DOT specification
 
-;;     Copyright (C) 2001, 2006 Free Software Foundation, Inc.
+;;     Copyright (C) 2001, 2006, 2011 Free Software Foundation, Inc.
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public License
@@ -53,6 +53,8 @@
                :select (make-frisker edge-type edge-up edge-down))
   :export (use2dot))
 
+(define %summary "Print a module's dependencies in graphviz format.")
+
 (define *default-module* '(guile-user))
 
 (define (q s)                           ; quote


hooks/post-receive
diff --git a/module/scripts/list.scm b/module/scripts/help.scm
similarity index 75%
copy from module/scripts/list.scm
copy to module/scripts/help.scm
index 6ffc016..9bb6ace 100644
--- a/module/scripts/list.scm
+++ b/module/scripts/help.scm
@@ -1,4 +1,4 @@
-;;; List --- List scripts that can be invoked by guild  -*- coding: iso-8859-1 
-*-
+;;; Help --- Show help on guild commands
 
 ;;;;   Copyright (C) 2009, 2010, 2011 Free Software Foundation, Inc.
 ;;;; 
@@ -19,16 +19,17 @@
 
 ;;; Commentary:
 
-;; Usage: list
+;; Usage: help
 ;;
 ;; List scripts that can be invoked by guild.
 
 ;;; Code:
 
-(define-module (scripts list)
+(define-module (scripts help)
   #:use-module (ice-9 format)
-  #:use-module ((srfi srfi-1) #:select (fold append-map))
-  #:export (list-scripts))
+  #:use-module ((srfi srfi-1) #:select (fold append-map)))
+
+(define %summary "Show a brief help message.")
 
 
 (define (directory-files dir)
@@ -90,19 +91,19 @@ Usage: guild COMMAND [ARGS]
 Commands:
 ")
 
-  (for-each
-   (lambda (name)
-     (let* ((modname `(scripts ,(string->symbol name)))
-            (mod (resolve-module modname #:ensure #f))
-            (summary (and mod (and=> (module-variable mod '%summary)
-                                     variable-ref))))
-       (if summary
-           (format #t "  ~A ~32t~a\n" name summary)
-           (format #t "  ~A\n" name))))
-   (find-submodules '(scripts)))
-
-  (display "\
-
-If COMMAND is \"list\" or omitted, display available scripts, otherwise
-COMMAND is run with ARGS.
-"))
+  (let ((all? (or (equal? args '("--all"))
+                  (equal? args '("-a")))))
+    (for-each
+     (lambda (name)
+       (let* ((modname `(scripts ,(string->symbol name)))
+              (mod (resolve-module modname #:ensure #f))
+              (summary (and mod (and=> (module-variable mod '%summary)
+                                       variable-ref))))
+         (if (and mod
+                  (or all?
+                      (let ((v (module-variable mod '%include-in-guild-list)))
+                        (if v (variable-ref v) #t))))
+             (if summary
+                 (format #t "  ~A ~23t~a\n" name summary)
+                 (format #t "  ~A\n" name)))))
+     (find-submodules '(scripts)))))
@@ -19,16 +19,17 @@
 ;;
-;; List scripts that can be invoked by guild.
+;; Show help for Guild scripts.
 
 ;;; Code:
-- 
GNU Guile



reply via email to

[Prev in Thread] Current Thread [Next in Thread]